--[[
Author: Starinnia
RealID Toons - Add character information to the BNet alerts your RealID friends generate
$Date: 2010-06-29 02:24:56 +0000 (Tue, 29 Jun 2010) $
$Revision: 13 $
Project Version: r13
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]
--save for the future
local myrealm = GetRealmName()

--create a reverse lookup from localized classes to english names
--we need the english names to get the class colors
local reverseClassLookup = {}
for k, v in pairs(LOCALIZED_CLASS_NAMES_FEMALE) do
	reverseClassLookup[v] = k
end
for k, v in pairs(LOCALIZED_CLASS_NAMES_MALE) do
	reverseClassLookup[v] = k
end

--pass in the presenceID of the friend
--from this we can obtain the character name, realm and class
local function constructToonName(presenceID)
	local _, toon, _, realm, _, _, class = BNGetToonInfo(presenceID)
	if not class then return end
	if RID_TOONS_COLOR then
		--pass the localized class into the lookup table, then the english class to
		local r, g, b = RAID_CLASS_COLORS[reverseClassLookup[class]].r*255, RAID_CLASS_COLORS[reverseClassLookup[class]].g*255, RAID_CLASS_COLORS[reverseClassLookup[class]].b*255
		toon = string.format("|cff%02x%02x%02x%s|r", r, g, b, toon)
	end
	if RID_TOONS_REALM and realm ~= myrealm then
		toon = toon.." - "..realm
	end
	
	return toon
end

local function filter(self, event, msg, author, ...)
	--the only toast we care about is FRIEND_ONLINE
	if msg ~= "FRIEND_ONLINE" then
		return false, msg, author, ...
	end
	
	local presenceID, givenName, surname, client, fullName
	local type = strsub(event, 10)
	local info = ChatTypeInfo[type]
	local arg11 = select(9, ...)
	
	--loop through the BNet friends to determine the toon name
	for i = 1, BNGetNumFriends() do
		presenceID, givenName, surname, _, _, client = BNGetFriendInfo(i)
		
		if not givenName or not surname then
			return false, msg, author, ...
		end
		
		fullName = string.format(BATTLENET_NAME_FORMAT, givenName, surname)
		--double check the client too, this will prevent strangeness when SC2 is released
		if client == "WoW" and author == fullName then
			--construct the playerlink and message prefix seperately for easier debugging
			local playerlink = string.format("|HBNplayer:%s:%s:%s:%s:%s|h[%s]|h", author, 7, arg11, Chat_GetChatCategory(type), 0, author)
			local prefix = string.format(BN_INLINE_TOAST_FRIEND_ONLINE, playerlink)
			--add a message to the passed in chat frame that looks like the regular toast
			local toonName = constructToonName(presenceID)
			if not toonName then
				return false, msg, author, ...
			end
			self:AddMessage(string.format("%s (%s)", prefix, toonName), info.r, info.g, info.b, info.id)
			
			--block the acual toast, it is replaced with our own
			return true, msg, author, ...
			
		--if the client is anything but WoW just return the real name
		elseif author == fullName then
			return false, msg, author, ...
		end
	end
end

ChatFrame_AddMessageEventFilter("CHAT_MSG_BN_INLINE_TOAST_ALERT", filter)

BNToastFrame:HookScript("OnShow", function()
	local topLine = BNToastFrameTopLine
	local bottomLine = BNToastFrameBottomLine
	
	--ensure that this toast is a friend coming online
	if string.match(bottomLine:GetText(), BN_TOAST_ONLINE) then
		local prefix = topLine:GetText()
		local presenceID, givenName, surname, client, fullName
		
		if not givenName or not surname then
			return
		end
		
		--loop through the BNet friends again
		for i = 1, BNGetNumFriends() do
			presenceID, givenName, surname, _, _, client = BNGetFriendInfo(i)
			fullName = string.format(BATTLENET_NAME_FORMAT, givenName, surname)
			--if its a WoW client add the toon name, otherwise only display the real name
			if client == "WoW" and prefix == fullName then
				local toonName = constructToonName(presenceID)
				if not toonName then return end
				topLine:SetFormattedText("%s (%s)", prefix, toonName)
				return
			elseif prefix == fullName then
				return
			end
		end
	end
end)
